@@ -176,9 +176,10 @@ typedef unsigned long ino_t;
 #define SIGUSR1 30	/* user defined signal 1 */
 #define SIGUSR2 31	/* user defined signal 2 */
 
-typedef unsigned short int ushort;
+#if !_SQUID_CYGWIN_
 typedef int uid_t;
 typedef int gid_t;
+#endif
 
 struct passwd {
     char    *pw_name;      /* user name */
@@ -253,16 +254,40 @@ typedef char * caddr_t;
 #undef FD_OPEN
 #undef FD_READ
 #undef FD_WRITE
+
+#ifndef EISCONN
 #define EISCONN WSAEISCONN
+#endif
+#ifndef EINPROGRESS
 #define EINPROGRESS WSAEINPROGRESS
+#endif
+#ifndef EWOULDBLOCK
 #define EWOULDBLOCK WSAEWOULDBLOCK
+#endif
+#ifndef EALREADY
 #define EALREADY WSAEALREADY
+#endif
+#ifndef ETIMEDOUT
 #define ETIMEDOUT WSAETIMEDOUT
+#endif
+#ifndef ECONNREFUSED
 #define ECONNREFUSED WSAECONNREFUSED
+#endif
+#ifndef ECONNRESET
 #define ECONNRESET WSAECONNRESET
+#endif
+#ifndef ENOTCONN
 #define ENOTCONN WSAENOTCONN
+#endif
+#ifndef ERESTART
 #define ERESTART WSATRY_AGAIN
+#endif
+#ifndef EAFNOSUPPORT
 #define EAFNOSUPPORT WSAEAFNOSUPPORT
+#endif
+#ifndef ENETUNREACH
+#define ENETUNREACH WSAENETUNREACH
+#endif
 
 #undef h_errno
 #define h_errno errno /* we'll set it ourselves */
@@ -705,6 +730,9 @@ int WSASocket(int a, int t, int p, LPWSAPROTOCOL_INFO i, GROUP g, DWORD f)
 #define open       _open /* Needed in win32lib.c */
 #endif /* #ifdef __cplusplus */
 
+#if HAVE_SYS_RESOURCE_H
+#include <sys/resource.h>
+#else
 #define	RUSAGE_SELF	0		/* calling process */
 #define	RUSAGE_CHILDREN	-1		/* terminated child processes */
 
@@ -726,6 +754,7 @@ struct rusage {
     long ru_nvcsw;			/* voluntary context switches */
     long ru_nivcsw;			/* involuntary context switches */
 };
+#endif /* HAVE_SYS_RESOURCE_H */
 
 #undef ACL
 
