@@ -1,5 +1,5 @@
 /*
- * $Id: MemObject.h,v 1.18 2008/02/26 21:49:34 amosjeffries Exp $
+ * $Id$
  *
  *
  * SQUID Web Proxy Cache          http://www.squid-cache.org/
@@ -77,7 +77,7 @@ public:
     void trimSwappable();
     void trimUnSwappable();
     bool isContiguous() const;
-    int mostBytesWanted(int max) const;
+    int mostBytesWanted(int max, bool ignoreDelayPools) const;
     void setNoDelay(bool const newValue);
 #if DELAY_POOLS
 
@@ -147,7 +147,7 @@ private:
     DeferredReadManager deferredReads;
 };
 
-MEMPROXY_CLASS_INLINE(MemObject)          /**DOCS_NOSEMI*/
+MEMPROXY_CLASS_INLINE(MemObject);
 
 /** global current memory removal policy */
 extern RemovalPolicy *mem_policy;
